@@ -40,7 +40,9 @@ pub mod prelude {
 /// * border_val: Scalar::all(0)
 #[inline]
 pub fn create_box_filter(src_type: i32, dst_type: i32, ksize: core::Size, anchor: core::Point, border_mode: i32, border_val: core::Scalar) -> Result<core::Ptr<dyn crate::cudafilters::Filter>> {
-	unsafe { sys::cv_cuda_createBoxFilter_int_int_Size_Point_int_Scalar(src_type, dst_type, ksize.opencv_as_extern(), anchor.opencv_as_extern(), border_mode, border_val.opencv_as_extern()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_cuda_createBoxFilter_int_int_Size_Point_int_Scalar(src_type, dst_type, ksize.opencv_as_extern(), anchor.opencv_as_extern(), border_mode, border_val.opencv_as_extern()) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates the maximum filter.
@@ -58,7 +60,9 @@ pub fn create_box_filter(src_type: i32, dst_type: i32, ksize: core::Size, anchor
 /// * border_val: Scalar::all(0)
 #[inline]
 pub fn create_box_max_filter(src_type: i32, ksize: core::Size, anchor: core::Point, border_mode: i32, border_val: core::Scalar) -> Result<core::Ptr<dyn crate::cudafilters::Filter>> {
-	unsafe { sys::cv_cuda_createBoxMaxFilter_int_Size_Point_int_Scalar(src_type, ksize.opencv_as_extern(), anchor.opencv_as_extern(), border_mode, border_val.opencv_as_extern()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_cuda_createBoxMaxFilter_int_Size_Point_int_Scalar(src_type, ksize.opencv_as_extern(), anchor.opencv_as_extern(), border_mode, border_val.opencv_as_extern()) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates the minimum filter.
@@ -76,7 +80,9 @@ pub fn create_box_max_filter(src_type: i32, ksize: core::Size, anchor: core::Poi
 /// * border_val: Scalar::all(0)
 #[inline]
 pub fn create_box_min_filter(src_type: i32, ksize: core::Size, anchor: core::Point, border_mode: i32, border_val: core::Scalar) -> Result<core::Ptr<dyn crate::cudafilters::Filter>> {
-	unsafe { sys::cv_cuda_createBoxMinFilter_int_Size_Point_int_Scalar(src_type, ksize.opencv_as_extern(), anchor.opencv_as_extern(), border_mode, border_val.opencv_as_extern()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_cuda_createBoxMinFilter_int_Size_Point_int_Scalar(src_type, ksize.opencv_as_extern(), anchor.opencv_as_extern(), border_mode, border_val.opencv_as_extern()) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates a vertical 1D box filter.
@@ -95,7 +101,9 @@ pub fn create_box_min_filter(src_type: i32, ksize: core::Size, anchor: core::Poi
 /// * border_val: Scalar::all(0)
 #[inline]
 pub fn create_column_sum_filter(src_type: i32, dst_type: i32, ksize: i32, anchor: i32, border_mode: i32, border_val: core::Scalar) -> Result<core::Ptr<dyn crate::cudafilters::Filter>> {
-	unsafe { sys::cv_cuda_createColumnSumFilter_int_int_int_int_int_Scalar(src_type, dst_type, ksize, anchor, border_mode, border_val.opencv_as_extern()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_cuda_createColumnSumFilter_int_int_int_int_int_Scalar(src_type, dst_type, ksize, anchor, border_mode, border_val.opencv_as_extern()) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates a generalized Deriv operator.
@@ -121,7 +129,9 @@ pub fn create_column_sum_filter(src_type: i32, dst_type: i32, ksize: i32, anchor
 /// * column_border_mode: -1
 #[inline]
 pub fn create_deriv_filter(src_type: i32, dst_type: i32, dx: i32, dy: i32, ksize: i32, normalize: bool, scale: f64, row_border_mode: i32, column_border_mode: i32) -> Result<core::Ptr<dyn crate::cudafilters::Filter>> {
-	unsafe { sys::cv_cuda_createDerivFilter_int_int_int_int_int_bool_double_int_int(src_type, dst_type, dx, dy, ksize, normalize, scale, row_border_mode, column_border_mode) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_cuda_createDerivFilter_int_int_int_int_int_bool_double_int_int(src_type, dst_type, dx, dy, ksize, normalize, scale, row_border_mode, column_border_mode) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates a Gaussian filter.
@@ -145,7 +155,9 @@ pub fn create_deriv_filter(src_type: i32, dst_type: i32, dx: i32, dy: i32, ksize
 /// * column_border_mode: -1
 #[inline]
 pub fn create_gaussian_filter(src_type: i32, dst_type: i32, ksize: core::Size, sigma1: f64, sigma2: f64, row_border_mode: i32, column_border_mode: i32) -> Result<core::Ptr<dyn crate::cudafilters::Filter>> {
-	unsafe { sys::cv_cuda_createGaussianFilter_int_int_Size_double_double_int_int(src_type, dst_type, ksize.opencv_as_extern(), sigma1, sigma2, row_border_mode, column_border_mode) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_cuda_createGaussianFilter_int_int_Size_double_double_int_int(src_type, dst_type, ksize.opencv_as_extern(), sigma1, sigma2, row_border_mode, column_border_mode) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates a Laplacian operator.
@@ -169,7 +181,9 @@ pub fn create_gaussian_filter(src_type: i32, dst_type: i32, ksize: core::Size, s
 /// * border_val: Scalar::all(0)
 #[inline]
 pub fn create_laplacian_filter(src_type: i32, dst_type: i32, ksize: i32, scale: f64, border_mode: i32, border_val: core::Scalar) -> Result<core::Ptr<dyn crate::cudafilters::Filter>> {
-	unsafe { sys::cv_cuda_createLaplacianFilter_int_int_int_double_int_Scalar(src_type, dst_type, ksize, scale, border_mode, border_val.opencv_as_extern()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_cuda_createLaplacianFilter_int_int_int_double_int_Scalar(src_type, dst_type, ksize, scale, border_mode, border_val.opencv_as_extern()) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates a non-separable linear 2D filter.
@@ -192,7 +206,9 @@ pub fn create_laplacian_filter(src_type: i32, dst_type: i32, ksize: i32, scale:
 #[inline]
 pub fn create_linear_filter(src_type: i32, dst_type: i32, kernel: &dyn core::ToInputArray, anchor: core::Point, border_mode: i32, border_val: core::Scalar) -> Result<core::Ptr<dyn crate::cudafilters::Filter>> {
 	input_array_arg!(kernel);
-	unsafe { sys::cv_cuda_createLinearFilter_int_int_const__InputArrayR_Point_int_Scalar(src_type, dst_type, kernel.as_raw__InputArray(), anchor.opencv_as_extern(), border_mode, border_val.opencv_as_extern()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_cuda_createLinearFilter_int_int_const__InputArrayR_Point_int_Scalar(src_type, dst_type, kernel.as_raw__InputArray(), anchor.opencv_as_extern(), border_mode, border_val.opencv_as_extern()) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Performs median filtering for each point of the source image.
@@ -212,7 +228,9 @@ pub fn create_linear_filter(src_type: i32, dst_type: i32, kernel: &dyn core::ToI
 /// * partition: 128
 #[inline]
 pub fn create_median_filter(src_type: i32, window_size: i32, partition: i32) -> Result<core::Ptr<dyn crate::cudafilters::Filter>> {
-	unsafe { sys::cv_cuda_createMedianFilter_int_int_int(src_type, window_size, partition) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_cuda_createMedianFilter_int_int_int(src_type, window_size, partition) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates a 2D morphological filter.
@@ -240,7 +258,9 @@ pub fn create_median_filter(src_type: i32, window_size: i32, partition: i32) ->
 #[inline]
 pub fn create_morphology_filter(op: i32, src_type: i32, kernel: &dyn core::ToInputArray, anchor: core::Point, iterations: i32) -> Result<core::Ptr<dyn crate::cudafilters::Filter>> {
 	input_array_arg!(kernel);
-	unsafe { sys::cv_cuda_createMorphologyFilter_int_int_const__InputArrayR_Point_int(op, src_type, kernel.as_raw__InputArray(), anchor.opencv_as_extern(), iterations) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_cuda_createMorphologyFilter_int_int_const__InputArrayR_Point_int(op, src_type, kernel.as_raw__InputArray(), anchor.opencv_as_extern(), iterations) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates a horizontal 1D box filter.
@@ -259,7 +279,9 @@ pub fn create_morphology_filter(op: i32, src_type: i32, kernel: &dyn core::ToInp
 /// * border_val: Scalar::all(0)
 #[inline]
 pub fn create_row_sum_filter(src_type: i32, dst_type: i32, ksize: i32, anchor: i32, border_mode: i32, border_val: core::Scalar) -> Result<core::Ptr<dyn crate::cudafilters::Filter>> {
-	unsafe { sys::cv_cuda_createRowSumFilter_int_int_int_int_int_Scalar(src_type, dst_type, ksize, anchor, border_mode, border_val.opencv_as_extern()) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_cuda_createRowSumFilter_int_int_int_int_int_Scalar(src_type, dst_type, ksize, anchor, border_mode, border_val.opencv_as_extern()) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates a vertical or horizontal Scharr operator.
@@ -283,7 +305,9 @@ pub fn create_row_sum_filter(src_type: i32, dst_type: i32, ksize: i32, anchor: i
 /// * column_border_mode: -1
 #[inline]
 pub fn create_scharr_filter(src_type: i32, dst_type: i32, dx: i32, dy: i32, scale: f64, row_border_mode: i32, column_border_mode: i32) -> Result<core::Ptr<dyn crate::cudafilters::Filter>> {
-	unsafe { sys::cv_cuda_createScharrFilter_int_int_int_int_double_int_int(src_type, dst_type, dx, dy, scale, row_border_mode, column_border_mode) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_cuda_createScharrFilter_int_int_int_int_double_int_int(src_type, dst_type, dx, dy, scale, row_border_mode, column_border_mode) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates a separable linear filter.
@@ -309,7 +333,9 @@ pub fn create_scharr_filter(src_type: i32, dst_type: i32, dx: i32, dy: i32, scal
 pub fn create_separable_linear_filter(src_type: i32, dst_type: i32, row_kernel: &dyn core::ToInputArray, column_kernel: &dyn core::ToInputArray, anchor: core::Point, row_border_mode: i32, column_border_mode: i32) -> Result<core::Ptr<dyn crate::cudafilters::Filter>> {
 	input_array_arg!(row_kernel);
 	input_array_arg!(column_kernel);
-	unsafe { sys::cv_cuda_createSeparableLinearFilter_int_int_const__InputArrayR_const__InputArrayR_Point_int_int(src_type, dst_type, row_kernel.as_raw__InputArray(), column_kernel.as_raw__InputArray(), anchor.opencv_as_extern(), row_border_mode, column_border_mode) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_cuda_createSeparableLinearFilter_int_int_const__InputArrayR_const__InputArrayR_Point_int_int(src_type, dst_type, row_kernel.as_raw__InputArray(), column_kernel.as_raw__InputArray(), anchor.opencv_as_extern(), row_border_mode, column_border_mode) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Creates a Sobel operator.
@@ -335,7 +361,9 @@ pub fn create_separable_linear_filter(src_type: i32, dst_type: i32, row_kernel:
 /// * column_border_mode: -1
 #[inline]
 pub fn create_sobel_filter(src_type: i32, dst_type: i32, dx: i32, dy: i32, ksize: i32, scale: f64, row_border_mode: i32, column_border_mode: i32) -> Result<core::Ptr<dyn crate::cudafilters::Filter>> {
-	unsafe { sys::cv_cuda_createSobelFilter_int_int_int_int_int_double_int_int(src_type, dst_type, dx, dy, ksize, scale, row_border_mode, column_border_mode) }.into_result().map(|r| unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(r) } )
+	let ret = unsafe { sys::cv_cuda_createSobelFilter_int_int_int_int_int_double_int_int(src_type, dst_type, dx, dy, ksize, scale, row_border_mode, column_border_mode) }.into_result()?;
+	let ret = unsafe { core::Ptr::<dyn crate::cudafilters::Filter>::opencv_from_extern(ret) };
+	Ok(ret)
 }
 
 /// Common interface for all CUDA filters :
@@ -360,7 +388,8 @@ pub trait Filter: core::AlgorithmTrait + crate::cudafilters::FilterConst {
 	fn apply(&mut self, src: &dyn core::ToInputArray, dst: &mut dyn core::ToOutputArray, stream: &mut core::Stream) -> Result<()> {
 		input_array_arg!(src);
 		output_array_arg!(dst);
-		unsafe { sys::cv_cuda_Filter_apply_const__InputArrayR_const__OutputArrayR_StreamR(self.as_raw_mut_Filter(), src.as_raw__InputArray(), dst.as_raw__OutputArray(), stream.as_raw_mut_Stream()) }.into_result()
+		let ret = unsafe { sys::cv_cuda_Filter_apply_const__InputArrayR_const__OutputArrayR_StreamR(self.as_raw_mut_Filter(), src.as_raw__InputArray(), dst.as_raw__OutputArray(), stream.as_raw_mut_Stream()) }.into_result()?;
+		Ok(ret)
 	}
 	
 }
