@@ -101,7 +101,7 @@ fn min_max_loc() -> Result<()> {
 	let mut m = Mat::new_rows_cols_with_default(10, 10, Vec3b::typ(), Scalar::all(5.))?;
 	let (mut min_val, mut max_val) = (90., 90.);
 	*m.at_2d_mut(5, 5)? = Vec3b::from([10, 20, 30]);
-	core::min_max_loc(&m, Some(&mut min_val), Some(&mut max_val), None, None, &core::no_array()?)?;
+	core::min_max_loc(&m, Some(&mut min_val), Some(&mut max_val), None, None, &core::no_array())?;
 	assert_eq!(5., min_val);
 	assert_eq!(30., max_val);
 	Ok(())
